@@ -7,6 +7,12 @@ crypto_sign_bytes(void)
     return crypto_sign_BYTES;
 }
 
+size_t
+crypto_sign_seedbytes(void)
+{
+    return crypto_sign_SEEDBYTES;
+}
+
 size_t
 crypto_sign_publickeybytes(void)
 {
@@ -53,3 +59,18 @@ crypto_sign_open(unsigned char *m, unsigned long long *mlen,
 {
     return crypto_sign_ed25519_open(m, mlen, sm, smlen, pk);
 }
+
+int
+crypto_sign_detached(unsigned char *sig, unsigned long long *siglen,
+                     const unsigned char *m, unsigned long long mlen,
+                     const unsigned char *sk)
+{
+    return crypto_sign_ed25519_detached(sig, siglen, m, mlen, sk);
+}
+
+int
+crypto_sign_verify_detached(const unsigned char *sig, const unsigned char *m,
+                            unsigned long long mlen, const unsigned char *pk)
+{
+    return crypto_sign_ed25519_verify_detached(sig, m, mlen, pk);
+}
